@@ -1,6 +1,6 @@
 package App::ansicolumn;
 
-our $VERSION = "1.48";
+our $VERSION = "1.49";
 
 use v5.14;
 use warnings;
@@ -10,7 +10,7 @@ use open IO => 'utf8', ':std';
 use Pod::Usage;
 use Getopt::EX::Long qw(:DEFAULT Configure ExConfigure);
 ExConfigure BASECLASS => [ __PACKAGE__, "Getopt::EX" ];
-Configure qw(bundling);
+Configure qw(bundling no_auto_abbrev no_ignore_case);
 
 use Data::Dumper;
 use List::Util qw(max sum min);
@@ -448,7 +448,7 @@ sub set_contents {
     my $obj = shift;
     my $fp = shift;
     my $dp = $fp->{data};
-    (my $cell_width = $obj->span - $obj->runin_margin) < 1
+    (my $cell_width = $obj->span) < 1
 	and die "Not enough space.\n";
     # Fold long lines
     if ($obj->linestyle and $obj->linestyle ne 'none') {
