@@ -459,6 +459,32 @@ my %template = (
 	right  => [ "⌎", " " , "⌌" ],
 	bottom => " ",
     },
+    bracket => {
+	top    => "",
+	left   => [ "┌ ", "│ ", "└ " ],
+	center => [ " ┐ ┌ ", " │ │ ", " ┘ └ " ],
+	right  => [ " ┐", " │" , " ┘" ],
+	bottom => "",
+    },
+    side_bracket => {
+	top    => "",
+	left   => [ "┌ ", "│ ", "└ " ],
+	center => [ " ╷ ", " │ ", " ╵ " ],
+	right  => [ " ┐", " │" , " ┘" ],
+	bottom => "",
+    },
+    left_bracket => {
+	top    => "",
+	left   => [ "┌ ", "│ ", "└ " ],
+	center  => [ "┌ ", "│ ", "└ " ],
+	bottom => "",
+    },
+    right_bracket => {
+	top    => "",
+	center => [ " ┐ ", " │ " , " ┘ " ],
+	right  => [ " ┐", " │" , " ┘ " ],
+	bottom => "",
+    },
     paren => {
 	top    => "",
 	left   => [ "⎛ ", "⎜ ", "⎝ " ],
@@ -470,7 +496,7 @@ my %template = (
 
 use Clone qw(clone);
 
-for my $style (qw(line vbar hline bottom_line box dash_box shadow_box ladder frame dash_frame page_frame comb rake mesh
+for my $style (qw(line vbar hline bottom_line box dash_box shadow_box ladder frame dash_frame page_frame comb rake mesh bracket side_bracket left_bracket right_bracket
 		  dumbbell ribbon)) {
     $template{$style} // next;
     my $new = $template{"heavy_$style"} = clone $template{$style};
